==> dongbei-lang-0.0.5.tar.gz: dongbei-lang-0.0.5/doc/cheatsheet.md <==
# dongbei 语言考试小抄

## 常量

### 常数

```
唠唠：零。  # 0
唠唠：鸭蛋。  # 0
唠唠：一。  # 1
唠唠：二。  # 2
唠唠：俩。  # 2
唠唠：两。  # 2
唠唠：三。  # 3
唠唠：仨。  # 3
唠唠：四。  # 4
唠唠：十。  # 10
唠唠：没毛病。  # True
唠唠：有毛病。  # False
```

## 变量

```
老张是活雷锋。  # 定义变量。初始值：啥也不是。
老张装二。  # 老张 = 2
削老张。  # 老张 = 啥也不是
老王是活雷锋。
老王装老张。  # 老王 = 啥也不是
老王装仨。  # 老王 = 3
老张装老王。  # 引用变量。老张 = 3
炮决老王。  # 老王尸骨无存了。
唠唠：老王。  # 整叉劈了：不认识老王。
```

## 群众

```
张家庄 都是活雷锋。  # 张家庄是个群众变量。初始值是「」。
张家庄 装「二加三，“大”」。  # 张家庄现在 = 「5, '大'」
张家庄 装 路银「二加三，“大”」。  # 意思一样。张家庄现在 = 「5, '大'」
张家庄 来了个 三。  # 张家庄现在 = 「5, '大', 3」。
唠唠：张家庄 掐头。  # 「'大', 3」
唠唠：张家庄 去尾。  # 「5, '大'」
唠唠：张家庄 有几个坑。  # 3
唠唠：张家庄 的老大。  # 第一个人（5）。
唠唠：张家庄 的老（三减一）。  # 第二个人（'大'）。
唠唠：张家庄 的老幺。  # 最后一个人（3）。
李家村 都是活雷锋。  # 李家村也是个群众变量。初始值是「」。
李家村 来了个 三。  # 李家村现在 = 「3」。
李家村 来了个 张家庄。  # 群众的一个元素本身可以是群众。李家村现在 = 「3, 「5, '大', 3」」。
李家村 来了群 张家庄。  # 把张家庄的群众挨个加入李家村。李家村现在 = 「3, 「5, '大', 3」, 5, '大', 3」。
炮决 李家村 的老三。  # 李家村现在 = 「3, 「5, '大', 3」, '大', 3」。
唠唠：李家村 的老二 的老大。  # 5。
削 张家庄。  # 张家庄现在啥也不是。
```

## 抱团

```
唠唠：抱团。  # ()
唠唠：五抱团。  # (5,)
唠唠：五跟六抱团。  # (5, 6)
老王装五跟六跟七抱团。  # (5, 6, 7)
唠唠：老王的老大。  # 5
唠唠：老王的老二。  # 6
唠唠：老王的老幺。  # 7
唠唠：老王有几个坑。  # 3
```

## 运算

```
老张 走走。  # 老张 += 1
老张 走两步。  # 老张 += 2
老张 稍稍。  # 老张 -= 1
老张 稍三步。  # 老张 -= 3
老张 装 老王 加 二。  # 老张 = 老王 + 2
老张 装（老张 减 三）除以 五 乘 老王。  # 老张 = (老张 - 3)/5*老王
老张 装 老张 齐整整地除以 老王。 # 老张 = (老张 / 老王)，只留整数部分
老张 装 老张 刨掉一堆堆 老王。 # 老张 = 老张除以老王的余数
老张 装 拉饥荒 老王。  # 老张 = - 老王
```

## 比较

```
老王比5还大
7加二比老刘还小
老张跟老王一样一样的
老李跟250不是一样一样的
老刘啥也不是
```

## 交流

```
唠唠：“唉呀妈呀”。  # 打印字符串常量。
唠唠：老王。  # 打印变量的值。
唠唠：老王比老张还大。  # 打印表达式的值。
唠唠：“老王是”、老王。  # 打印两个表达式的并置。
唠唠：最高指示。  # 打印当前命令行。
贵姓 装 整你吱声（“你贵姓？”）。  # 等待用户输入。
```

## 条件

```
寻思：老王比老张还大？
要行咧就唠唠：“老王！”。
要不行咧就唠唠：“老张！”。
```

## 循环

```
老王从1到10磨叽：
  唠唠：老王。
磨叽完了！

老张在张家庄磨叽：
  寻思：老张比二还大？
  要行咧就开整：
    唠唠：老张。
    接着磨叽。  # continue
  整完了。
  要不行咧就尥蹶子！  # break
磨叽完了。
```

## 组合

```
寻思：老王比老张还大？
要行咧就开整：
  唠唠：“老王！”。
  唠唠：“你好美！”。
整完了。
```

## 套路

```
【阶乘】（那啥）咋整：  # 定义套路 阶乘，有一个参数 那啥。
  寻思：那啥比一还小？ # 需要自推吗？
  要行咧就 滚犊子吧 一。  # 返回值1。
  要不行咧就 滚犊子吧 那啥乘整【阶乘】（那啥减一）。  # 需要。返回自推结果。
整完了。  # 定义结束。

唠唠：整【阶乘】（五）！  # 使用套路
```

## 阶级

```
# 定义 有名 class, 没有 parent class。
无产阶级的接班银 有名 阶级咋整：
  新对象（名字）咋整：  # 定义初始化 有名class 对象的方法。
    俺的名字 装 名字。  # 将对象的名字属性设成参数的值。
  整完了。
整完了。

# 创建一个有名class的新对象，参数为“林蛋大”。
老林 装 有名的新对象（“林蛋大”）。
唠唠：老林的名字。  # 林蛋大

 # 定义 特有名 class，parent class 是 有名。
有名阶级的接班银 特有名 阶级咋整：
  新对象咋整：  # 定义初始化 有名class 对象的方法。没有参数。
    # 调用 有名 阶级的初始化方法。
    整 领导的新对象（“赵英俊”）。
    # 特有名 阶级特有的操作。
    俺的 年龄 装 25。
  整完了。

  公岁咋整：
    滚犊子吧 俺的 年龄 除以 二。
  整完了。

  显呗咋整：
    唠唠：“我你都不认识啊？我是那啥”、俺的名字、“！”。
  整完了。
整完了。

老赵 装 特有名的新对象。
唠唠：老赵 整 公岁。  # 12.5
老赵 整 显呗。
```

## 帮衬

```
翠花，上 math。  # 导入 python math 模块。
唠唠：整 math.factorial（五）。  # 整个 python 套路。
```

==> dongbei-lang-0.0.11.tar.gz: dongbei-lang-0.0.11/doc/cheatsheet.md <==
# dongbei 语言考试小抄

## 常量

### 常数

```
唠唠：零。  # 0
唠唠：鸭蛋。  # 0
唠唠：一。  # 1
唠唠：二。  # 2
唠唠：俩。  # 2
唠唠：两。  # 2
唠唠：三。  # 3
唠唠：仨。  # 3
唠唠：四。  # 4
唠唠：十。  # 10
唠唠：没毛病。  # True
唠唠：有毛病。  # False
```

## 变量

```
老张是活雷锋。  # 定义变量。初始值：啥也不是。
老张装二。  # 老张 = 2
削老张。  # 老张 = 啥也不是
老王是活雷锋。
老王装老张。  # 老王 = 啥也不是
老王装仨。  # 老王 = 3
老张装老王。  # 引用变量。老张 = 3
炮决老王。  # 老王尸骨无存了。
唠唠：老王。  # 整叉劈了：不认识老王。
```

## 群众

```
张家庄 都是活雷锋。  # 张家庄是个群众变量。初始值是「」。
张家庄 装「二加三，“大”」。  # 张家庄现在 = 「5, '大'」
张家庄 装 路银「二加三，“大”」。  # 意思一样。张家庄现在 = 「5, '大'」
张家庄 来了个 三。  # 张家庄现在 = 「5, '大', 3」。
唠唠：张家庄 掐头。  # 「'大', 3」
唠唠：张家庄 去尾。  # 「5, '大'」
唠唠：张家庄 有几个坑。  # 3
唠唠：张家庄 的老大。  # 第一个人（5）。
唠唠：张家庄 的老（三减一）。  # 第二个人（'大'）。
唠唠：张家庄 的老幺。  # 最后一个人（3）。
李家村 都是活雷锋。  # 李家村也是个群众变量。初始值是「」。
李家村 来了个 三。  # 李家村现在 = 「3」。
李家村 来了个 张家庄。  # 群众的一个元素本身可以是群众。李家村现在 = 「3, 「5, '大', 3」」。
李家村 来了群 张家庄。  # 把张家庄的群众挨个加入李家村。李家村现在 = 「3, 「5, '大', 3」, 5, '大', 3」。
炮决 李家村 的老三。  # 李家村现在 = 「3, 「5, '大', 3」, '大', 3」。
唠唠：李家村 的老二 的老大。  # 5。
削 张家庄。  # 张家庄现在啥也不是。
```

## 抱团

```
唠唠：抱团。  # ()
唠唠：五抱团。  # (5,)
唠唠：五跟六抱团。  # (5, 6)
老王装五跟六跟七抱团。  # (5, 6, 7)
唠唠：老王的老大。  # 5
唠唠：老王的老二。  # 6
唠唠：老王的老幺。  # 7
唠唠：老王有几个坑。  # 3
```

## 运算

```
老张 走走。  # 老张 += 1
老张 走两步。  # 老张 += 2
老张 稍稍。  # 老张 -= 1
老张 稍三步。  # 老张 -= 3
老张 装 老王 加 二。  # 老张 = 老王 + 2
老张 装（老张 减 三）除以 五 乘 老王。  # 老张 = (老张 - 3)/5*老王
老张 装 老张 齐整整地除以 老王。 # 老张 = (老张 / 老王)，只留整数部分
老张 装 老张 刨掉一堆堆 老王。 # 老张 = 老张除以老王的余数
老张 装 拉饥荒 老王。  # 老张 = - 老王
```

## 比较

```
老王比5还大
7加二比老刘还小
老张跟老王一样一样的
老李跟250不是一样一样的
老刘啥也不是
```

## 交流

```
唠唠：“唉呀妈呀”。  # 打印字符串常量。
唠唠：老王。  # 打印变量的值。
唠唠：老王比老张还大。  # 打印表达式的值。
唠唠：“老王是”、老王。  # 打印两个表达式的并置。
唠唠：最高指示。  # 打印当前命令行。
贵姓 装 整你吱声（“你贵姓？”）。  # 等待用户输入。
```

## 条件

```
寻思：老王比老张还大？
要行咧就唠唠：“老王！”。
要不行咧就唠唠：“老张！”。
```

## 循环

```
老王从1到10磨叽：
  唠唠：老王。
磨叽完了！

老张在张家庄磨叽：
  寻思：老张比二还大？
  要行咧就开整：
    唠唠：老张。
    接着磨叽。  # continue
  整完了。
  要不行咧就尥蹶子！  # break
磨叽完了。

老张在苹果总部磨叽：  # 无限循环 - 苹果总部在 1 Infinite Loop
  唠唠：老张。  # 总是打印“1”。
磨叽完了。

老张从一而终磨叽：  # 无限循环
  唠唠：老张。  # 总是打印“1”。
磨叽完了。

老张从三到十一步两蹿磨叽：
  唠唠：老张。  # 依次打印 3，5，7，9。
磨叽完了。
```

## 组合

```
寻思：老王比老张还大？
要行咧就开整：
  唠唠：“老王！”。
  唠唠：“你好美！”。
整完了。
```

## 套路

```
【阶乘】（那啥）咋整：  # 定义阶乘套路，有一个参数：那啥。
  寻思：那啥比一还小？ # 需要自推吗？
  要行咧就 滚犊子吧 一。  # 返回值1。
  要不行咧就 滚犊子吧 那啥乘整【阶乘】（那啥减一）。  # 需要。返回自推结果。
整完了。  # 定义结束。

唠唠：整【阶乘】（五）！  # 使用套路

平方数 咋整：  # 定义平方数套路，用于列举所有平方数。这个套路没参数。
  数学老师 装 一。
  老王 从一而终磨叽：
    数学老师 乘 数学老师 出溜。  # 蹦出一个结果但是不返回。
    数学老师 走走。
  磨叽完了。
整完了。

# 使用带出溜的套路。打印前十个平方数。
小明 在 整 平方数 磨叽：
  寻思：小明比 100 还大？
  要行咧就 尥蹶子！
  唠唠：小明。
磨叽完了。
```

## 阶级

```
# 定义 有名 class, 没有 parent class。
无产阶级的接班银 有名 阶级咋整：
  新对象（名字）咋整：  # 定义初始化 有名class 对象的方法。
    俺的名字 装 名字。  # 将对象的名字属性设成参数的值。
  整完了。
整完了。

# 创建一个有名class的新对象，参数为“林蛋大”。
老林 装 有名的新对象（“林蛋大”）。
唠唠：老林的名字。  # 林蛋大

 # 定义 特有名 class，parent class 是 有名。
有名阶级的接班银 特有名 阶级咋整：
  新对象咋整：  # 定义初始化 有名class 对象的方法。没有参数。
    # 调用 有名 阶级的初始化方法。
    整 领导的新对象（“赵英俊”）。
    # 特有名 阶级特有的操作。
    俺的 年龄 装 25。
  整完了。

  公岁咋整：
    滚犊子吧 俺的 年龄 除以 二。
  整完了。

  显呗咋整：
    唠唠：“我你都不认识啊？我是那啥”、俺的名字、“！”。
  整完了。
整完了。

老赵 装 特有名的新对象。
唠唠：老赵 整 公岁。  # 12.5
老赵 整 显呗。
```

## 帮衬

```
翠花，上 math。  # 导入 python math 模块。
唠唠：整 math.factorial（五）。  # 整个 python 套路。
```
